def locations(roll, trademark, start, end):
    
    roll = roll.loc[roll['Trademark']==trademark]
    roll_loc = roll.sort_values(by=['WeekNo']).drop_duplicates(subset='SerialNumber', keep='first')
    roll_loc.loc[(roll_loc['WeekNo'] > start-1) & (roll_loc['WeekNo'] < end+1), 'Status'] = 'New'
    roll_loc['Status'] = roll_loc['Status'].fillna('Existing')
    roll_loc = roll_loc.reset_index(drop=True)
    
    return roll_loc



import pandas as pd

def loc(unit, ref, trademark):
    
    roll = unit.loc[unit['Trademark']==trademark]
    ref = ref.loc[ref['Trademark']==trademark]
    
    roll_loc = pd.merge(roll, ref[['SerialNumber', 'Status']], on='SerialNumber', how='left')
    roll_loc = roll_loc.reset_index(drop=True)
    
    roll_loc = roll_loc.sort_values(by=['Date']).drop_duplicates(subset='SerialNumber', keep='first')
    roll_loc = roll_loc.groupby(['Operator Name', 'WeekNo', 'Status'])['SerialNumber'].nunique()

    def to_frame(sets):
        sets = sets.to_frame().reset_index()
        return sets 
    
    roll_loc = to_frame(roll_loc)
    roll_loc['Trademark'] = trademark
    
    return roll_loc

def sales(unit, ref, trademark):
    
    roll = unit.loc[unit['Trademark']==trademark]
    ref = ref.loc[ref['Trademark']==trademark]
    
    roll_sales = pd.merge(roll, ref[['SerialNumber', 'Status']], on='SerialNumber', how='left')
    roll_sales = roll_sales.reset_index(drop=True)
    
    roll_sales = roll_sales.groupby(['Operator Name', 'WeekNo', 'Status'])['SalesCount'].sum()
    
    def to_frame(sets):
        sets = sets.to_frame().reset_index()
        return sets 
    
    roll_sales = to_frame(roll_sales)
    roll_sales['Trademark'] = trademark 
    
    return roll_sales


import pandas as pd

def dashStatus(dash, ref, trademark):
    
    dash1 = dash.loc[dash['Trademark']==trademark]
    ref = ref.loc[ref['Trademark']==trademark]
    
    dashboard = pd.merge(dash1, ref[['SerialNumber', 'Status']], on='SerialNumber', how='left')
    dashboard = dashboard.reset_index(drop=True)
    
    metrics = dashboard.groupby(['Trademark', 'Operator Name', 'Status'])[['SalesCount', 'NetSalesRevenue', 'Transactions']].sum()
    metrics = metrics.reset_index()
    metrics['Avg Price'] = (metrics['NetSalesRevenue'] / metrics['SalesCount'])
 
    return metrics




import pandas as pd 

def rawDash(roll, imp, trademark, start, end):
    
    unit_set = roll.loc[roll['Trademark']==trademark]
    unit_set = unit_set.loc[(unit_set['WeekNo']>start-1)&(unit_set['WeekNo'] < end+1)]
    
    imp_set = imp.loc[imp['Trademark']==trademark]
    imp_set = imp_set.loc[(imp_set['WeekNo'] > start-1) & (imp_set['WeekNo'] < end+1)]
    
    op_unit = unit_set.groupby(['Operator Name', 'SerialNumber'])['SalesCount'].sum()
    op_sales = unit_set.groupby(['Operator Name', 'SerialNumber'])['NetSalesRevenue'].sum()
    op_imp = imp_set.groupby(['Operator Name', 'SerialNumber'])['Transactions'].sum()
    
    def to_frame(sets):
        sets = sets.to_frame()
        sets = sets.reset_index()
        return sets 
    
    op_metrics = pd.merge(to_frame(op_unit), to_frame(op_sales)[['NetSalesRevenue', 'SerialNumber']], on='SerialNumber', how='left')
    op_metrics = pd.merge(op_metrics, to_frame(op_imp)[['Transactions', 'SerialNumber']], on='SerialNumber', how='left')
    op_metrics['Trademark'] = trademark
    op_metrics = op_metrics.reset_index(drop=True)
    
    return op_metrics




import pandas as pd 

def active_unit(unit, master, trademark):
    unit_set = pd.merge(unit, master[['Operator Name', 'SerialNumber', trademark]], on='SerialNumber', how='left')
    unit_set = unit_set.loc[unit_set[trademark]=='Yes']
    unit_set = unit_set.rename(columns={trademark: 'Active'})
    unit_set['Trademark'] = trademark
    unit_set = unit_set.reset_index()
    
    return unit_set

def active_imp(imp, master, trademark):
    imp_set = pd.merge(imp, master[['Operator Name', 'SerialNumber', trademark]], on='SerialNumber', how='left')
    imp_set = imp_set.loc[imp_set[trademark]=='Yes']
    imp_set = imp_set.rename(columns={trademark:'Active'})
    imp_set['Trademark'] = trademark
    imp_set = imp_set.reset_index()
    
    return imp_set

def active_day(day, master, trademark):
    day_set = pd.merge(day, master[['Operator Name', 'SerialNumber', trademark]], on='SerialNumber', how='left')
    day_set = day_set.loc[day_set[trademark]=='Yes']
    day_set = day_set.rename(columns={trademark: 'Active'})
    day_set['Trademark'] = trademark
    day_set = day_set.reset_index()
    
    return day_set


import pandas as pd 

def daypartAnalysis(day, ref, trademark):
    
    daypart = day.loc[day['Trademark']==trademark]
    ref = ref.loc[ref['Trademark']==trademark]
    
    daypart = pd.merge(daypart, ref[['SerialNumber','Status']], on='SerialNumber', how='left')
    daypart = daypart.groupby(['Operator Name', 'Hour', 'Status'])['TransID'].nunique()
    daypart = daypart.to_frame().reset_index()
    average = daypart['TransID'].mean()
    daypart['Transactions'] = (daypart['TransID']/average)*100
    daypart['Trademark'] = trademark
    
    return daypart 
